body#visual-portal-wrapper {
    &.pat-plone {
        #edit-bar {
            #edit-zone {
                .contenttype-bando:after {
                    content: "";
                    background-image: url("/++plone++rer.bandi.images/bando_icon.svg");
                    background-position: center;
                    background-repeat: no-repeat;
                    background-size: 1em;
                }
            }
        }
    }
}

.visualClear {
    clear: both;
}

.rer-contextual-portlets-right {
    width: 17em;
    margin-left: 1em;
    float: right;
}

body.portaltype-bando {
    #content {
        .rer-contextual-text,
        .rer-contextual-portlets {
            a {
                background: none;
                padding: 1px 0 1px 1px;
                text-decoration: underline;
            }
        }
    }
}

.rer-contextual-description {
    margin-bottom: 10px;
}

.contextualbody .navTreeItem li {
    list-style-type: none;
}

.rer-contextual-portlets ul {
    margin: 0.5em 0 0 0.5em;
}

.contextualbody {
    .navTreeItem {
        &,
        dd.portletItem & {
            a {
                display: inline;
            }
        }
    }
}

.tableRight {
    width: 100%;
}

.bandiColumnRight {
    width: 40%;
    float: right;
    margin-left: 1em;
}

/*** etichette bandi ***/

.bandoInfos,
.bandoTitle {
    .bandoStateClass {
        background-position: 5px 0;
        background-repeat: no-repeat;
        display: block;
        float: left;
        font-size: 0.8em;
        font-weight: normal;
        margin-right: 1em;
        padding-top: 5px;
        text-transform: uppercase;
        width: 57px;
        min-width: 57px;
        text-align: center;
    }
}

a.bandoTitle {
    border-bottom: 1px solid #cccccc;
    text-decoration: none;
}

a.bandoTitleLink {
    border-bottom: 1px solid;
}

.bandoStateClass {
    .bandoInfos & {
        margin-top: 4px;
    }

    .bandoTitle & {
        font-size: 70%;
        margin-bottom: 0;
        margin-top: 7px;
        text-align: center;

        .searchResults & {
            margin-top: 3px;
        }
    }
}

h3.bandoTitle {
    margin-top: 0;
    padding: 0;
}

h2.bandoTitle,
.bandoInfos {
    position: relative;
    padding: 15px 0;

    .tileContent & {
        padding-left: 75px;

        .bandoStateClass {
            position: absolute;
            top: 2em;
            left: 0;
        }
    }

    .searchResults & {
        .bandoStateClass {
            float: left;
        }
    }

    .state-open,
    .state-inProgress,
    .state-closed {
        // float: none;
        padding: 10px 0 5px;
        // color: #666;
        // font-weight: 600;
        // border-top: 5px solid;
    }

    .state-open {
        background-image: url(++plone++rer.bandi.images/bando_open.png);
        color: #255a01;
        // border-color: #27af0f;
    }

    .state-inProgress {
        background-image: url(++plone++rer.bandi.images/bando_inprogress.png);
        color: #9c6f02;
        // border-color: #e5c001;
    }

    .state-closed {
        background-image: url(++plone++rer.bandi.images/bando_closed.png);
        color: #700;
        // border-color: #c00;
    }
}

h2.bandoTitle {
    font-size: 120%;
    font-weight: normal;
    margin-top: 2em;
}

.bandoDetail {
    clear: both;
}

.bandoDetail,
.searchResults .bandoDetail {
    margin: 0 0 0 70px;
    clear: none;
}

.bandoItem {
    border-bottom: 1px dashed #ccc;
    padding: 0.5em 0 0.7em;
    margin: 0.5em 0;
}

.labelTB {
    font-weight: bold;
}

.bandoDates {
    display: flex;
    flex-wrap: wrap;

    .colspacer {
        padding: 0 10px;
    }
}

p.bandoType {
    color: #666;
    font-size: 0.9em;
    font-style: italic;
    margin: 0;
}

.siteSelection {
    margin-left: 2em;
    margin-top: 1em;
}

.collectionTile.no-description {
    .bandoDescription {
        display: none;
    }
}

.solr-search-actions {
    > p {
        margin-top: 15px;
        margin-bottom: 0;
    }
}

.solr-search-actions,
.solr-search-results {
    a {
        border-bottom: 1px solid;
    }
}

.bandi-collection {
    .tile-wrapper {
        padding: 20px 0;
        position: relative;
    }

    .showMore {
        position: absolute;
        top: 20px;
        right: 0;
        padding: 10px 0;
    }

    .showMore a {
        border-bottom: 1px solid;
    }

    ul.tileContent {
        padding-left: 0;
    }
}
