"""Common configuration constants
"""

PROJECTNAME = 'rer.bandi'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'BandoFolderDeepening': 'rer.bandi: Add Bando Folder Deepening',
    'Bando': 'rer.bandi: Add Bando',
}
