body#visual-portal-wrapper.pat-plone #edit-bar #edit-zone .contenttype-bando:after {
  content: "";
  background-image: url("/++plone++rer.bandi.images/bando_icon.svg");
  background-position: center;
  background-repeat: no-repeat;
  background-size: 1em; }

.visualClear {
  clear: both; }

.rer-contextual-portlets-right {
  width: 17em;
  margin-left: 1em;
  float: right; }

body.portaltype-bando #content .rer-contextual-text a,
body.portaltype-bando #content .rer-contextual-portlets a {
  background: none;
  padding: 1px 0 1px 1px;
  text-decoration: underline; }

.rer-contextual-description {
  margin-bottom: 10px; }

.contextualbody .navTreeItem li {
  list-style-type: none; }

.rer-contextual-portlets ul {
  margin: 0.5em 0 0 0.5em; }

.contextualbody .navTreeItem a, dd.portletItem .contextualbody .navTreeItem a {
  display: inline; }

.tableRight {
  width: 100%; }

.bandiColumnRight {
  width: 40%;
  float: right;
  margin-left: 1em; }

/*** etichette bandi ***/
.bandoInfos .bandoStateClass,
.bandoTitle .bandoStateClass {
  background-position: 5px 0;
  background-repeat: no-repeat;
  display: block;
  float: left;
  font-size: 0.8em;
  font-weight: normal;
  margin-right: 1em;
  padding-top: 5px;
  text-transform: uppercase;
  width: 57px;
  min-width: 57px;
  text-align: center; }

a.bandoTitle {
  border-bottom: 1px solid #cccccc;
  text-decoration: none; }

a.bandoTitleLink {
  border-bottom: 1px solid; }

.bandoInfos .bandoStateClass {
  margin-top: 4px; }
.bandoTitle .bandoStateClass {
  font-size: 70%;
  margin-bottom: 0;
  margin-top: 7px;
  text-align: center; }
  .searchResults .bandoTitle .bandoStateClass {
    margin-top: 3px; }

h3.bandoTitle {
  margin-top: 0;
  padding: 0; }

h2.bandoTitle,
.bandoInfos {
  position: relative;
  padding: 15px 0; }
  .tileContent h2.bandoTitle, .tileContent
  .bandoInfos {
    padding-left: 75px; }
    .tileContent h2.bandoTitle .bandoStateClass, .tileContent
    .bandoInfos .bandoStateClass {
      position: absolute;
      top: 2em;
      left: 0; }
  .searchResults h2.bandoTitle .bandoStateClass, .searchResults
  .bandoInfos .bandoStateClass {
    float: left; }
  h2.bandoTitle .state-open,
  h2.bandoTitle .state-inProgress,
  h2.bandoTitle .state-closed,
  .bandoInfos .state-open,
  .bandoInfos .state-inProgress,
  .bandoInfos .state-closed {
    padding: 10px 0 5px; }
  h2.bandoTitle .state-open,
  .bandoInfos .state-open {
    background-image: url(++plone++rer.bandi.images/bando_open.png);
    color: #255a01; }
  h2.bandoTitle .state-inProgress,
  .bandoInfos .state-inProgress {
    background-image: url(++plone++rer.bandi.images/bando_inprogress.png);
    color: #9c6f02; }
  h2.bandoTitle .state-closed,
  .bandoInfos .state-closed {
    background-image: url(++plone++rer.bandi.images/bando_closed.png);
    color: #700; }

h2.bandoTitle {
  font-size: 120%;
  font-weight: normal;
  margin-top: 2em; }

.bandoDetail {
  clear: both; }

.bandoDetail,
.searchResults .bandoDetail {
  margin: 0 0 0 70px;
  clear: none; }

.bandoItem {
  border-bottom: 1px dashed #ccc;
  padding: 0.5em 0 0.7em;
  margin: 0.5em 0; }

.labelTB {
  font-weight: bold; }

.bandoDates {
  display: flex;
  flex-wrap: wrap; }
  .bandoDates .colspacer {
    padding: 0 10px; }

p.bandoType {
  color: #666;
  font-size: 0.9em;
  font-style: italic;
  margin: 0; }

.siteSelection {
  margin-left: 2em;
  margin-top: 1em; }

.collectionTile.no-description .bandoDescription {
  display: none; }

.solr-search-actions > p {
  margin-top: 15px;
  margin-bottom: 0; }

.solr-search-actions a,
.solr-search-results a {
  border-bottom: 1px solid; }

.bandi-collection .tile-wrapper {
  padding: 20px 0;
  position: relative; }
.bandi-collection .showMore {
  position: absolute;
  top: 20px;
  right: 0;
  padding: 10px 0; }
.bandi-collection .showMore a {
  border-bottom: 1px solid; }
.bandi-collection ul.tileContent {
  padding-left: 0; }

/*# sourceMappingURL=bandi.css.map */
